R/Enrichments.R
PlotEnrichments.RdPlotEnrichments performs and plots enrichment analyses for a list of
DESeqResults objects as generated by RunDESeq2 or
ProcessDEGs or a list of data.frames as generated by
RunDiffBind or ProcessDBRs. It queries the
enrichr web server to do so. Results are saved both as tables and plots.
PlotEnrichments(res.list, outpath, padj.thresh, fc.thresh, libraries, chip = FALSE)
| res.list | Either:
|
|---|---|
| outpath | Path to directory to be used for output. Additional directories will be generated within this folder. |
| padj.thresh | Number indicating the adjusted p-value
cutoff to be used for determining "significant" differential expression
or differential binding (if |
| fc.thresh | Number indicating the log2 fold-change
cutoff to be used for determining "significant" differential expression.
or differential binding (if |
| libraries | A vector of valid |
| chip | Boolean indicating whether |
Available libraries can be viewed with listEnrichrDbs
from the enrichR package.
The enrichr web server can be found at https://amp.pharm.mssm.edu/Enrichr/. If you use this function, you should be sure to cite the original authors.
RunEnrichr, VizEnrichments, and
enrichr for additional enrichment options.
ProcessDEGs for generating DESeqResults objects.
ProcessDBRs, for generating csAnno objects.